@@ -11,7 +11,7 @@ use File::Basename;
 use File::Spec::Functions;
 
 BEGIN {
-	$VERSION = '0.25_03';
+	$VERSION = '0.25_05';
 	}
 
 =head1 NAME
@@ -24,18 +24,18 @@ CPAN::PackageDetails - Create or read 02packages.details.txt.gz
 
 	# read an existing file #####################
 	my $package_details = CPAN::PackageDetails->read( $filename );
-	
+
 	my $count      = $package_details->count;
-	
+
 	my $records    = $package_details->entries;
-	
+
 	foreach my $record ( @$records )
 		{
 		# See CPAN::PackageDetails::Entry too
 		print join "\t", map { $record->$_() } ('package name', 'version', 'path')
 		print join "\t", map { $record->$_() } $package_details->columns_as_list;
 		}
-		
+
 	# not yet implemented, but would be really, really cool eh?
 	my $records    = $package_details->entries(
 		logic   => 'OR',  # but that could be AND, which is the default
@@ -43,9 +43,9 @@ CPAN::PackageDetails - Create or read 02packages.details.txt.gz
 		author  => 'OVID',      # case insenstive
 		path    =>  qr/foo/,
 		);
-	
+
 	# create a new file #####################
-	my $package_details = CPAN::PackageDetails->new( 
+	my $package_details = CPAN::PackageDetails->new(
 		file         => "02packages.details.txt",
 		url          => "http://example.com/MyCPAN/modules/02packages.details.txt",
 		description  => "Package names for my private CPAN",
@@ -54,6 +54,7 @@ CPAN::PackageDetails - Create or read 02packages.details.txt.gz
 		written_by   => "$0 using CPAN::PackageDetails $CPAN::PackageDetails::VERSION",
 		last_updated => CPAN::PackageDetails->format_date,
 		allow_packages_only_once => 1,
+		disallow_alpha_versions  => 1,
 		);
 
 	$package_details->add_entry(
@@ -61,15 +62,15 @@ CPAN::PackageDetails - Create or read 02packages.details.txt.gz
 		version      => $package->VERSION;
 		path         => $path,
 		);
-		
+
 	print "About to write ", $package_details->count, " entries\n";
-	
+
 	$package_details->write_file( $file );
-	
+
 	 # OR ...
-	 
+
 	$package_details->write_fh( \*STDOUT )
-	
+
 =head1 DESCRIPTION
 
 CPAN uses an index file, F<02packages.details.txt.gz>, to map package names to
@@ -106,7 +107,12 @@ method shows you which values you can pass to C<new>. For instance:
 		)
 
 If you specify the C<allow_packages_only_once> option with a true value
-and you try to add that package twice, the object will die. See C<add_entry>.
+and you try to add that package twice, the object will die. See C<add_entry>
+in C<CPAN::PackageDetails::Entries>.
+
+If you specify the C<disallow_alpha_versions> option with a true value
+and you try to add that package twice, the object will die. See C<add_entry>
+in C<CPAN::PackageDetails::Entries>.
 
 =cut
 
@@ -123,13 +129,13 @@ sub new
 			if( $@ ) {
 				croak "You must have DBM::Deep installed and discoverable to use the dbmdeep feature";
 				}
-			my $ref = DBM::Deep->new( 
-				file => $args{dbmdeep}, 
+			my $ref = DBM::Deep->new(
+				file => $args{dbmdeep},
 				autoflush => 1,
 				);
 			croak "Could not create DBM::Deep object" unless ref $ref;
 			my $single_class = sprintf "${class}::DBM%03d", $class_counter++;
-			
+
 			no strict 'refs';
 			@{"${single_class}::ISA"} = ( $class , 'DBM::Deep' );
 			( $ref, $single_class );
@@ -139,11 +145,11 @@ sub new
 			( {}, $class );
 			}
 		};
-		
+
 	my $self = bless $ref, $bless_class;
-	
+
 	$self->init( %args );
-	
+
 	$self;
 	}
 }
@@ -175,13 +181,13 @@ BEGIN {
 # them to the right delegate
 my %Dispatch = (
 		header  => { map { $_, 1 } qw(default_headers get_header set_header header_exists columns_as_list) },
-		entries => { map { $_, 1 } qw(add_entry count as_unique_sorted_list already_added allow_packages_only_once get_entries_by_package get_entries_by_version get_entries_by_path get_entries_by_distribution) },
+		entries => { map { $_, 1 } qw(add_entry count as_unique_sorted_list already_added allow_packages_only_once disallow_alpha_versions get_entries_by_package get_entries_by_version get_entries_by_path get_entries_by_distribution) },
 	#	entry   => { map { $_, 1 } qw() },
 		);
-		
+
 my %Dispatchable = map { #inverts %Dispatch
-	my $class = $_; 
-	map { $_, $class } keys %{$Dispatch{$class}} 
+	my $class = $_;
+	map { $_, $class } keys %{$Dispatch{$class}}
 	} keys %Dispatch;
 
 sub can
@@ -192,8 +198,8 @@ sub can
 
 	foreach my $method ( @methods )
 		{
-		next if 
-			defined &{"${class}::$method"} || 
+		next if
+			defined &{"${class}::$method"} ||
 			exists $Dispatchable{$method}  ||
 			$self->header_exists( $method );
 		return 0;
@@ -205,15 +211,15 @@ sub can
 sub AUTOLOAD
 	{
 	my $self = shift;
-	
-	
+
+
 	our $AUTOLOAD;
 	carp "There are no AUTOLOADable class methods: $AUTOLOAD" unless ref $self;
 	( my $method = $AUTOLOAD ) =~ s/.*:://;
-	
+
 	if( exists $Dispatchable{$method} )
 		{
-		my $delegate = $Dispatchable{$method};	
+		my $delegate = $Dispatchable{$method};
 		return $self->$delegate()->$method(@_)
 		}
 	elsif( $self->header_exists( $method ) )
@@ -242,8 +248,9 @@ my %defaults = (
 	entry_class     => 'CPAN::PackageDetails::Entry',
 
 	allow_packages_only_once => 1,
+	disallow_alpha_versions  => 0,
 	);
-	
+
 sub init
 	{
 	my( $self, %args ) = @_;
@@ -256,35 +263,36 @@ sub init
 		$self->{$key}  = $config{$key};
 		delete $config{$key};
 		}
-	
+
 	foreach my $class ( map { $self->$_ } qw(header_class entries_class entry_class) )
 		{
 		eval "require $class";
 		}
 
-	# don't initialize things if they are already there. For instance, 
+	# don't initialize things if they are already there. For instance,
 	# if we read an existing DBM::Deep file
 	$self->{entries} = $self->entries_class->new(
 		entry_class              => $self->entry_class,
 		columns                  => [ split /,\s+/, $config{columns} ],
 		allow_packages_only_once => $config{allow_packages_only_once},
+		disallow_alpha_versions  => $config{disallow_alpha_versions},
 		) unless exists $self->{entries};
-	
+
 	$self->{header}  = $self->header_class->new(
 		_entries => $self->entries,
 		) unless exists $self->{header};
-	
-	
+
+
 	foreach my $key ( keys %config )
 		{
 		$self->header->set_header( $key, $config{$key} );
 		}
 
-	$self->header->set_header( 
-		'last_updated', 
-		$self->header->format_date 
+	$self->header->set_header(
+		'last_updated',
+		$self->header->format_date
 		);
-		
+
 	}
 
 }
@@ -298,7 +306,7 @@ identifiers. The field is lowercased, and then hyphens become
 underscores. For instance:
 
 	Written-By ---> written_by
-	
+
 =cut
 
 sub read
@@ -310,7 +318,7 @@ sub read
 		carp "Missing argument!";
 		return;
 		}
-		
+
 	require IO::Uncompress::Gunzip;
 
 	my $fh = IO::Uncompress::Gunzip->new( $file ) or do {
@@ -318,14 +326,14 @@ sub read
 		carp "Could not open $file: $IO::Compress::Gunzip::GunzipError\n";
 		return;
 		};
-	
+
 	my $self = $class->_parse( $fh );
-	
+
 	$self->{source_file} = $file;
-	
-	$self;	
+
+	$self;
 	}
-	
+
 =item source_file
 
 Returns the original file path for objects created through the
@@ -340,32 +348,32 @@ sub _parse
 	my( $class, $fh ) = @_;
 
 	my $package_details = $class->new;
-		
+
 	while( <$fh> ) # header processing
 		{
 		chomp;
 		my( $field, $value ) = split /\s*:\s*/, $_, 2;
-		
+
 		$field = lc $field;
 		$field =~ tr/-/_/;
-		
+
 		carp "Unknown field value [$field] at line $.! Skipping..."
 			unless 1; # XXX should there be field name restrictions?
 		$package_details->set_header( $field, $value );
 		last if /^\s*$/;
 		}
-	
+
 	my @columns = $package_details->columns_as_list;
 	while( <$fh> ) # entry processing
 		{
 		chomp;
 		my @values = split; # this could be in any order based on columns field.
-		$package_details->add_entry( 
+		$package_details->add_entry(
 			map { $columns[$_], $values[$_] } 0 .. $#columns
 			)
 		}
-	
-	$package_details;	
+
+	$package_details;
 	}
 
 =item write_file( OUTPUT_FILE )
@@ -374,7 +382,7 @@ Formats the object as a string and writes it to a temporary file and
 gzips the output. When everything is complete, it renames the temporary
 file to its final name.
 
-C<write_file> carps and returns nothing if you pass it no arguments, if 
+C<write_file> carps and returns nothing if you pass it no arguments, if
 it cannot open OUTPUT_FILE for writing, or if it cannot rename the file.
 
 =cut
@@ -388,23 +396,23 @@ sub write_file
 		carp "Missing argument!";
 		return;
 		}
-	
+
 	require IO::Compress::Gzip;
-	
+
 	my $fh = IO::Compress::Gzip->new( "$output_file.$$" ) or do {
 		carp "Could not open $output_file.$$ for writing: $IO::Compress::Gzip::GzipError";
 		return;
 		};
-	
+
 	$self->write_fh( $fh );
 	$fh->close;
-	
+
 	unless( rename "$output_file.$$", $output_file )
 		{
 		carp "Could not rename temporary file to $output_file!\n";
 		return;
 		}
-		
+
 	return 1;
 	}
 
@@ -417,10 +425,10 @@ Formats the object as a string and writes it to FILEHANDLE
 sub write_fh
 	{
 	my( $self, $fh ) = @_;
-	
+
 	print $fh $self->header->as_string, $self->entries->as_string;
 	}
-	
+
 =item check_file( FILE, CPAN_PATH )
 
 This method takes an existing F<02packages.details.txt.gz> named in FILE and
@@ -439,20 +447,20 @@ with these keys:
 	filename                the FILE you passed in
 	cpan_path               the CPAN_PATH you passed in
 	cwd                     the current working directory
-	error_count             
+	error_count
 
 	# if FILE is missing
 	missing_file          exists and true if FILE doesn't exist
 
 	# if the entry count in the file is wrong
 	# that is, the actual line count and header disagree
-	entry_count_mismatch    true 
-	line_count              the line count declared in the header   
+	entry_count_mismatch    true
+	line_count              the line count declared in the header
 	entry_count             the actual count
 
-	# if some distros in CPAN_HOME are missing in FILE		
+	# if some distros in CPAN_HOME are missing in FILE
 	missing_in_file         anonymous array of missing paths
-	
+
 	# if some entries in FILE are missing the file in CPAN_HOME
 	missing_in_repo         anonymous array of missing paths
 
@@ -471,14 +479,14 @@ sub check_file
 	# subclasses, so if the higher level application just has the
 	# object, and maybe from a class I don't know about, they should
 	# be able to call this method and have it end up here if they
-	# didn't override it. That is, don't encourage them to hard code 
+	# didn't override it. That is, don't encourage them to hard code
 	# a class name
 	my $class = ref $either || $either;
-	
+
 	# file exists
-	my $error = { 
-		error_count => 0, 
-		cpan_path   => $cpan_path, 
+	my $error = {
+		error_count => 0,
+		cpan_path   => $cpan_path,
 		filename    => $file,
 		cwd         => cwd(),
 		};
@@ -487,17 +495,17 @@ sub check_file
 		$error->{missing_file}         = 1;
 		$error->{error_count}         +=  1;
 		}
-		
+
 	# file is gzipped
 
 	# check header # # # # # # # # # # # # # # # # # # #
 	my $packages = $class->read( $file );
-	
+
 	# count of entries in non-zero # # # # # # # # # # # # # # # # # # #
 
 	my $header_count = $packages->get_header( 'line_count' );
 	my $entries_count = $packages->count;
-	
+
 	unless( $header_count )
 		{
 		$error->{entry_count_mismatch} = 1;
@@ -518,14 +526,14 @@ sub check_file
 		{
 		my $missing_in_file = $packages->check_for_missing_dists_in_file( $cpan_path );
 		my $missing_in_repo = $packages->check_for_missing_dists_in_repo( $cpan_path );
-		
+
 		$error->{missing_in_file}  =  $missing_in_file if @$missing_in_file;
 		$error->{missing_in_repo}  =  $missing_in_repo if @$missing_in_repo;
 		$error->{error_count}     += @$missing_in_file  + @$missing_in_repo;
 		}
 
 	croak $error if $error->{error_count};
-	
+
 	return 1;
 	}
 
@@ -533,7 +541,7 @@ sub check_file
 
 =item check_for_missing_dists_in_repo( CPAN_PATH )
 
-Given an object and a CPAN_PATH, return an anonymous array of the 
+Given an object and a CPAN_PATH, return an anonymous array of the
 distributions in the object that are not in CPAN_PATH. That is,
 complain when the object has extra distributions.
 
@@ -551,18 +559,18 @@ sub check_for_missing_dists_in_repo
 	foreach my $entry ( @$entries )
 		{
 		my $path = $entry->path;
-		
+
 		my $native_path = catfile( $cpan_path, split m|/|, $path );
-		
+
 		push @missing, $path unless -e $native_path;
 		}
-		
+
 	return \@missing;
 	}
 
 =item check_for_missing_dists_in_file( CPAN_PATH )
 
-Given an object and a CPAN_PATH, return an anonymous array of the 
+Given an object and a CPAN_PATH, return an anonymous array of the
 distributions in CPAN_PATH that do not show up in the object. That is,
 complain when the object doesn't have all the dists.
 
@@ -574,30 +582,30 @@ error output.
 sub check_for_missing_dists_in_file
 	{
 	my( $packages, $cpan_path ) = @_;
-	
+
 	my $dists = $packages->_get_repo_dists( $cpan_path );
-	
+
 	$packages->_filter_older_dists( $dists );
-	
+
 	my %files = map { $_, 1 } @$dists;
 	use Data::Dumper;
-	
+
 	my( $entries ) = $packages->as_unique_sorted_list;
 
 	foreach my $entry ( @$entries )
 		{
 		my $path = $entry->path;
-		my $native_path = catfile( $cpan_path, split m|/|, $path );			
+		my $native_path = catfile( $cpan_path, split m|/|, $path );
 		delete $files{$native_path};
 		}
-	
+
 	[ keys %files ];
 	}
 
 sub _filter_older_dists
 	{
 	my( $self, $array ) = @_;
-	
+
 	my %Seen;
 	my @order;
 	require  CPAN::DistnameInfo;
@@ -607,7 +615,7 @@ sub _filter_older_dists
 		my( $name, $version, $developer ) = CPAN::DistnameInfo::distname_info( $basename );
 		my $tuple = [ $path, $name, $version ];
 		push @order, $name;
-		
+
 		   # first branch, haven't seen the distro yet
 		   if( ! exists $Seen{ $name } )        { $Seen{ $name } = $tuple }
 		   # second branch, the version we see now is greater than before
@@ -615,8 +623,8 @@ sub _filter_older_dists
 		   # third branch, nothing. Really? Are you sure there's not another case?
 		else                                   { () }
 		}
-		
-	@$array = map { 
+
+	@$array = map {
 		if( exists $Seen{$_} )
 			{
 			my $dist = $Seen{$_}[0];
@@ -628,15 +636,15 @@ sub _filter_older_dists
 			()
 			}
 		} @order;
-	
+
 	return 1;
 	}
 
 
-sub _distname_info 
+sub _distname_info
 	{
 	my $file = shift or return;
-	
+
 	my ($dist, $version) = $file =~ /^
 		(                          # start of dist name
 			(?:
@@ -649,7 +657,7 @@ sub _distname_info
 						|
 					_(?=\D)
 				)*
-	 			
+
 	 			(?:
 					[A-Za-z]
 					(?=
@@ -661,7 +669,7 @@ sub _distname_info
 					\d
 					(?=-)
 	 			)
-	 			
+
 	 			(?<!
 	 				[._-][vV]
 	 			)
@@ -692,23 +700,23 @@ sub _distname_info
 	# deal with versions with extra information
 	$version =~ s/-build\d+.*//;
 	$version =~ s/-DRW.*//;
-	
+
 	# deal with perl versions, merely to see if it is a dev version
 	my $dev;
-	if( length $version ) 
+	if( length $version )
 		{
 		$dev = do {
-			if ($file =~ /^perl-?\d+\.(\d+)(?:\D(\d+))?(-(?:TRIAL|RC)\d+)?$/) 
+			if ($file =~ /^perl-?\d+\.(\d+)(?:\D(\d+))?(-(?:TRIAL|RC)\d+)?$/)
 				{
 				 1 if (($1 > 6 and $1 & 1) or ($2 and $2 >= 50)) or $3;
 				}
-			elsif ($version =~ /\d\D\d+_\d/) 
+			elsif ($version =~ /\d\D\d+_\d/)
 				{
 				1;
 				}
 			};
 		}
-	else 
+	else
 		{
 		$version = undef;
 		}
@@ -717,24 +725,24 @@ sub _distname_info
 	}
 
 sub _get_repo_dists
-	{	
+	{
 	my( $self, $cpan_home ) = @_;
-				   
+
 	my @files = ();
-	
+
 	use File::Find;
-	
-	my $wanted = sub { 
-		push @files, 
-			File::Spec::Functions::canonpath( $File::Find::name ) 
-				if m/\.(?:tar\.gz|tgz|zip)\z/ 
+
+	my $wanted = sub {
+		push @files,
+			File::Spec::Functions::canonpath( $File::Find::name )
+				if m/\.(?:tar\.gz|tgz|zip)\z/
 			};
-	
+
 	find( $wanted, $cpan_home );
-	
+
 	return \@files;
 	}
-        
+
 sub DESTROY {}
 
 =back
@@ -758,7 +766,7 @@ sub header_class { $_[0]->{header_class} }
 Returns the header object.
 
 =cut
-	
+
 sub header { $_[0]->{header} }
 
 =back
@@ -770,11 +778,11 @@ sub header { $_[0]->{header} }
 =cut
 
 =back
-	
+
 =head2 Entries
 
 Entries are the collection of the items describing the package details.
-It comprises all of the Entry object. 
+It comprises all of the Entry object.
 
 =head3 Methods is CPAN::PackageDetails
 
@@ -802,7 +810,7 @@ This dispatches to the C<count> in CPAN::PackageDetails::Entries. These
 are the same:
 
 	$package_details->count;
-	
+
 	$package_details->entries->count;
 
 =cut
@@ -850,14 +858,14 @@ sub _entries { $_[0]->{_entries} }
 This source is in Github:
 
 	http://github.com/briandfoy/cpan-packagedetails
-	
+
 =head1 AUTHOR
 
 brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009, brian d foy, All Rights Reserved.
+Copyright (c) 2009-2011, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
